@@ -108,7 +108,7 @@ enum
 
 static guint drop_signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (ClutterDropAction, clutter_drop_action, CLUTTER_TYPE_ACTION)
+G_DEFINE_TYPE_WITH_PRIVATE (ClutterDropAction, clutter_drop_action, CLUTTER_TYPE_ACTION)
 
 static void
 drop_target_free (gpointer _data)
@@ -127,24 +127,40 @@ on_stage_capture (ClutterStage *stage,
 {
   DropTarget *data = user_data;
   gfloat event_x, event_y;
-  ClutterInputDevice *device;
   ClutterActor *actor, *drag_actor;
   ClutterDropAction *drop_action;
   gboolean was_reactive;
 
-  if (!(clutter_event_type (event) == CLUTTER_MOTION ||
-        clutter_event_type (event) == CLUTTER_BUTTON_RELEASE))
-    return CLUTTER_EVENT_PROPAGATE;
+  switch (clutter_event_type (event))
+    {
+    case CLUTTER_MOTION:
+    case CLUTTER_BUTTON_RELEASE:
+      {
+        ClutterInputDevice *device;
 
-  if (!(clutter_event_get_state (event) & CLUTTER_BUTTON1_MASK))
-    return CLUTTER_EVENT_PROPAGATE;
+        if (!(clutter_event_get_state (event) & CLUTTER_BUTTON1_MASK))
+          return CLUTTER_EVENT_PROPAGATE;
+
+        device = clutter_event_get_device (event);
+        drag_actor = _clutter_stage_get_pointer_drag_actor (stage, device);
+        if (drag_actor == NULL)
+          return CLUTTER_EVENT_PROPAGATE;
+      }
+      break;
+
+    case CLUTTER_TOUCH_UPDATE:
+    case CLUTTER_TOUCH_END:
+      drag_actor = _clutter_stage_get_touch_drag_actor (stage,
+                                                        clutter_event_get_event_sequence (event));
+      if (drag_actor == NULL)
+        return CLUTTER_EVENT_PROPAGATE;
+      break;
+
+    default:
+      return CLUTTER_EVENT_PROPAGATE;
+    }
 
   clutter_event_get_coords (event, &event_x, &event_y);
-  device = clutter_event_get_device (event);
-
-  drag_actor = _clutter_stage_get_drag_actor (stage, device);
-  if (drag_actor == NULL)
-    return CLUTTER_EVENT_PROPAGATE;
 
   /* get the actor under the cursor, excluding the dragged actor; we
    * use reactivity because it won't cause any scene invalidation
@@ -210,7 +226,8 @@ on_stage_capture (ClutterStage *stage,
     }
 
 out:
-  if (clutter_event_type (event) == CLUTTER_BUTTON_RELEASE)
+  if (clutter_event_type (event) == CLUTTER_BUTTON_RELEASE ||
+      clutter_event_type (event) == CLUTTER_TOUCH_END)
     {
       if (data->last_action != NULL)
         {
@@ -367,8 +384,6 @@ clutter_drop_action_class_init (ClutterDropActionClass *klass)
 {
   ClutterActorMetaClass *meta_class = CLUTTER_ACTOR_META_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (ClutterDropActionPrivate));
-
   meta_class->set_actor = clutter_drop_action_set_actor;
 
   klass->can_drop = clutter_drop_action_real_can_drop;
@@ -501,8 +516,7 @@ clutter_drop_action_class_init (ClutterDropActionClass *klass)
 static void
 clutter_drop_action_init (ClutterDropAction *self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, CLUTTER_TYPE_DROP_ACTION,
-                                            ClutterDropActionPrivate);
+  self->priv = clutter_drop_action_get_instance_private (self);
 }
 
 /**
