@@ -276,4 +276,32 @@
 # define CLUTTER_AVAILABLE_IN_1_14
 #endif
 
+#if CLUTTER_VERSION_MIN_REQUIRED >= CLUTTER_VERSION_1_16
+# define CLUTTER_DEPRECATED_IN_1_16             CLUTTER_DEPRECATED
+# define CLUTTER_DEPRECATED_IN_1_16_FOR(f)      CLUTTER_DEPRECATED_FOR(f)
+#else
+# define CLUTTER_DEPRECATED_IN_1_16
+# define CLUTTER_DEPRECATED_IN_1_16_FOR(f)
+#endif
+
+#if CLUTTER_VERSION_MAX_ALLOWED < CLUTTER_VERSION_1_16
+# define CLUTTER_AVAILABLE_IN_1_16              CLUTTER_UNAVAILABLE(1, 16)
+#else
+# define CLUTTER_AVAILABLE_IN_1_16
+#endif
+
+#if CLUTTER_VERSION_MIN_REQUIRED >= CLUTTER_VERSION_1_18
+# define CLUTTER_DEPRECATED_IN_1_18             CLUTTER_DEPRECATED
+# define CLUTTER_DEPRECATED_IN_1_18_FOR(f)      CLUTTER_DEPRECATED_FOR(f)
+#else
+# define CLUTTER_DEPRECATED_IN_1_18
+# define CLUTTER_DEPRECATED_IN_1_18_FOR(f)
+#endif
+
+#if CLUTTER_VERSION_MAX_ALLOWED < CLUTTER_VERSION_1_18
+# define CLUTTER_AVAILABLE_IN_1_18              CLUTTER_UNAVAILABLE(1, 18)
+#else
+# define CLUTTER_AVAILABLE_IN_1_18
+#endif
+
 #endif /* __CLUTTER_MACROS_H__ */
