@@ -112,12 +112,6 @@
 
 #include "deprecated/clutter-timeline.h"
 
-static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
-
-G_DEFINE_TYPE_WITH_CODE (ClutterTimeline, clutter_timeline, G_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
-                                                clutter_scriptable_iface_init));
-
 struct _ClutterTimelinePrivate
 {
   ClutterTimelineDirection direction;
@@ -210,6 +204,13 @@ enum
 
 static guint timeline_signals[LAST_SIGNAL] = { 0, };
 
+static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
+
+G_DEFINE_TYPE_WITH_CODE (ClutterTimeline, clutter_timeline, G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (ClutterTimeline)
+                         G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
+                                                clutter_scriptable_iface_init))
+
 static TimelineMarker *
 timeline_marker_new_time (const gchar *name,
                           guint        msecs)
@@ -575,8 +576,6 @@ clutter_timeline_class_init (ClutterTimelineClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (ClutterTimelinePrivate));
-
   /**
    * ClutterTimeline:loop:
    *
@@ -846,21 +845,17 @@ clutter_timeline_class_init (ClutterTimelineClass *klass)
 static void
 clutter_timeline_init (ClutterTimeline *self)
 {
-  ClutterTimelinePrivate *priv;
+  self->priv = clutter_timeline_get_instance_private (self);
 
-  self->priv = priv =
-    G_TYPE_INSTANCE_GET_PRIVATE (self, CLUTTER_TYPE_TIMELINE,
-                                 ClutterTimelinePrivate);
-
-  priv->progress_mode = CLUTTER_LINEAR;
+  self->priv->progress_mode = CLUTTER_LINEAR;
 
   /* default steps() parameters are 1, end */
-  priv->n_steps = 1;
-  priv->step_mode = CLUTTER_STEP_MODE_END;
+  self->priv->n_steps = 1;
+  self->priv->step_mode = CLUTTER_STEP_MODE_END;
 
   /* default cubic-bezier() paramereters are (0, 0, 1, 1) */
-  clutter_point_init (&priv->cb_1, 0, 0);
-  clutter_point_init (&priv->cb_2, 1, 1);
+  clutter_point_init (&self->priv->cb_1, 0, 0);
+  clutter_point_init (&self->priv->cb_2, 1, 1);
 }
 
 struct CheckIfMarkerHitClosure
@@ -2452,9 +2447,9 @@ clutter_timeline_get_step_progress (ClutterTimeline *timeline,
 {
   g_return_val_if_fail (CLUTTER_IS_TIMELINE (timeline), FALSE);
 
-  if (timeline->priv->progress_mode != CLUTTER_STEPS ||
-      timeline->priv->progress_mode != CLUTTER_STEP_START ||
-      timeline->priv->progress_mode != CLUTTER_STEP_END)
+  if (!(timeline->priv->progress_mode == CLUTTER_STEPS ||
+        timeline->priv->progress_mode == CLUTTER_STEP_START ||
+        timeline->priv->progress_mode == CLUTTER_STEP_END))
     return FALSE;
 
   if (n_steps != NULL)
@@ -2496,6 +2491,11 @@ clutter_timeline_set_cubic_bezier_progress (ClutterTimeline    *timeline,
 
   priv->cb_1 = *c_1;
   priv->cb_2 = *c_2;
+
+  /* ensure the range on the X coordinate */
+  priv->cb_1.x = CLAMP (priv->cb_1.x, 0.f, 1.f);
+  priv->cb_2.x = CLAMP (priv->cb_2.x, 0.f, 1.f);
+
   clutter_timeline_set_progress_mode (timeline, CLUTTER_CUBIC_BEZIER);
 }
 
@@ -2521,11 +2521,11 @@ clutter_timeline_get_cubic_bezier_progress (ClutterTimeline *timeline,
 {
   g_return_val_if_fail (CLUTTER_IS_TIMELINE (timeline), FALSE);
 
-  if (timeline->priv->progress_mode != CLUTTER_CUBIC_BEZIER ||
-      timeline->priv->progress_mode != CLUTTER_EASE ||
-      timeline->priv->progress_mode != CLUTTER_EASE_IN ||
-      timeline->priv->progress_mode != CLUTTER_EASE_OUT ||
-      timeline->priv->progress_mode != CLUTTER_EASE_IN_OUT)
+  if (!(timeline->priv->progress_mode == CLUTTER_CUBIC_BEZIER ||
+        timeline->priv->progress_mode == CLUTTER_EASE ||
+        timeline->priv->progress_mode == CLUTTER_EASE_IN ||
+        timeline->priv->progress_mode == CLUTTER_EASE_OUT ||
+        timeline->priv->progress_mode == CLUTTER_EASE_IN_OUT))
     return FALSE;
 
   if (c_1 != NULL)
