@@ -36,20 +36,22 @@
  * The #ClutterTableLayout is a #ClutterLayoutManager implementing the
  * following layout policy:
  *
- *   - children are arranged in a table
- *   - each child specifies the specific row and column
- *   cell to appear;
- *   - a child can also set a span, and this way, take
- *   more than one cell both horizontally and vertically;
- *   - each child will be allocated to its natural
- *   size or, if set to expand, the available size;
- *   - if a child is set to fill on either (or both)
+ * <itemizedlist>
+ *   <listitem><para>children are arranged in a table</para></listitem>
+ *   <listitem><para>each child specifies the specific row and column
+ *   cell to appear;</para></listitem>
+ *   <listitem><para>a child can also set a span, and this way, take
+ *   more than one cell both horizontally and vertically;</para></listitem>
+ *   <listitem><para>each child will be allocated to its natural
+ *   size or, if set to expand, the available size;</para></listitem>
+ *   <listitem><para>if a child is set to fill on either (or both)
  *   axis, its allocation will match all the available size; the
  *   fill layout property only makes sense if the expand property is
- *   also set;
- *   - if a child is set to expand but not to fill then
+ *   also set;</para></listitem>
+ *   <listitem><para>if a child is set to expand but not to fill then
  *   it is possible to control the alignment using the horizontal and
- *   vertical alignment layout properties.
+ *   vertical alignment layout properties.</para></listitem>
+ * </itemizedlist>
  *
  * It is possible to control the spacing between children of a
  * #ClutterTableLayout by using clutter_table_layout_set_row_spacing()
@@ -65,11 +67,19 @@
  * #ClutterTableLayout:easing-mode and #ClutterTableLayout:easing-duration
  * properties and their accessor functions.
  *
+ * <figure id="table-layout-image">
+ *   <title>Table layout</title>
+ *   <para>The image shows a #ClutterTableLayout.</para>
+ *   <graphic fileref="table-layout.png" format="PNG"/>
+ * </figure>
+ *
  * #ClutterTableLayout is available since Clutter 1.4
  *
  * Since Clutter 1.18 it's recommended to use #ClutterGridLayout instead
  * of #ClutterTableLayout; the former supports right-to-left text direction,
  * as well as using the alignment and expansion flags on #ClutterActor.
+ *
+ * Deprecated: 1.18
  */
 
 #ifdef HAVE_CONFIG_H
@@ -724,7 +734,7 @@ calculate_col_widths (ClutterTableLayout *self,
       DimensionData *col;
       gfloat c_min, c_pref;
 
-      if (!clutter_actor_is_visible (child))
+      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
         continue;
 
       meta =
@@ -766,7 +776,7 @@ calculate_col_widths (ClutterTableLayout *self,
       gint start_col, end_col;
       gint n_expand;
 
-      if (!clutter_actor_is_visible (child))
+      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
         continue;
 
       meta =
@@ -1001,7 +1011,7 @@ calculate_row_heights (ClutterTableLayout *self,
       DimensionData *row;
       gfloat c_min, c_pref;
 
-      if (!clutter_actor_is_visible (child))
+      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
         continue;
 
       meta =
@@ -1044,7 +1054,7 @@ calculate_row_heights (ClutterTableLayout *self,
       gint start_row, end_row;
       gint n_expand;
 
-      if (!clutter_actor_is_visible (child))
+      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
         continue;
 
       meta =
@@ -1405,7 +1415,7 @@ clutter_table_layout_allocate (ClutterLayoutManager   *layout,
       gdouble x_align, y_align;
       gboolean x_fill, y_fill;
 
-      if (!clutter_actor_is_visible (child))
+      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
         continue;
 
       meta =
@@ -1621,7 +1631,7 @@ clutter_table_layout_class_init (ClutterTableLayoutClass *klass)
    *
    * Since: 1.4
    *
-   * Deprecated: 1.18: Use #ClutterGridLayout:column-spacing instead
+   * Deprecated: 1.18
    */
   pspec = g_param_spec_uint ("column-spacing",
                              P_("Column Spacing"),
@@ -1637,7 +1647,7 @@ clutter_table_layout_class_init (ClutterTableLayoutClass *klass)
    *
    * Since: 1.4
    *
-   * Deprecated: 1.18: Use #ClutterGridLayout:row-spacing instead
+   * Deprecated: 1.18
    */
   pspec = g_param_spec_uint ("row-spacing",
                              P_("Row Spacing"),
@@ -1762,7 +1772,7 @@ clutter_table_layout_new (void)
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: Use #ClutterGridLayout:column-spacing instead
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 void
 clutter_table_layout_set_column_spacing (ClutterTableLayout *layout,
@@ -1797,7 +1807,7 @@ clutter_table_layout_set_column_spacing (ClutterTableLayout *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: Use #ClutterGridLayout:column-spacing
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 guint
 clutter_table_layout_get_column_spacing (ClutterTableLayout *layout)
@@ -1816,7 +1826,7 @@ clutter_table_layout_get_column_spacing (ClutterTableLayout *layout)
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: Use #ClutterGridLayout:row-spacing instead
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 void
 clutter_table_layout_set_row_spacing (ClutterTableLayout *layout,
@@ -1851,7 +1861,7 @@ clutter_table_layout_set_row_spacing (ClutterTableLayout *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: Use #ClutterGridLayout:row-spacing instead
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 guint
 clutter_table_layout_get_row_spacing (ClutterTableLayout *layout)
@@ -1873,7 +1883,7 @@ clutter_table_layout_get_row_spacing (ClutterTableLayout *layout)
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: Use clutter_grid_layout_attach_child() instead
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 void
 clutter_table_layout_pack (ClutterTableLayout  *layout,
@@ -1929,8 +1939,7 @@ clutter_table_layout_pack (ClutterTableLayout  *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: Use the `width` and `height` layout properties
- *   of #ClutterGridLayout instead
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 void
 clutter_table_layout_set_span (ClutterTableLayout *layout,
@@ -1986,8 +1995,7 @@ clutter_table_layout_set_span (ClutterTableLayout *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: Use the `width` and `height` layout properties
- *   of #ClutterGridLayout instead
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 void
 clutter_table_layout_get_span (ClutterTableLayout *layout,
@@ -2405,8 +2413,7 @@ clutter_table_layout_get_expand (ClutterTableLayout *layout,
  * Since: 1.4
  *
  * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them. See clutter_actor_set_easing_mode()
- *   and clutter_actor_set_easing_duration().
+ *   of the children when allocating them
  */
 void
 clutter_table_layout_set_use_animations (ClutterTableLayout *layout,
@@ -2439,9 +2446,7 @@ clutter_table_layout_set_use_animations (ClutterTableLayout *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them. See clutter_actor_set_easing_mode()
- *   and clutter_actor_set_easing_duration().
+ * Deprecated: 1.12
  */
 gboolean
 clutter_table_layout_get_use_animations (ClutterTableLayout *layout)
@@ -2466,8 +2471,7 @@ clutter_table_layout_get_use_animations (ClutterTableLayout *layout)
  * Since: 1.4
  *
  * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them. See clutter_actor_set_easing_mode()
- *   and clutter_actor_set_easing_duration().
+ *   of the children when allocating them
  */
 void
 clutter_table_layout_set_easing_mode (ClutterTableLayout *layout,
@@ -2498,8 +2502,7 @@ clutter_table_layout_set_easing_mode (ClutterTableLayout *layout,
  * Since: 1.4
  *
  * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them. See clutter_actor_set_easing_mode()
- *   and clutter_actor_set_easing_duration().
+ *   of the children when allocating them
  */
 gulong
 clutter_table_layout_get_easing_mode (ClutterTableLayout *layout)
@@ -2524,8 +2527,7 @@ clutter_table_layout_get_easing_mode (ClutterTableLayout *layout)
  * Since: 1.4
  *
  * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them. See clutter_actor_set_easing_mode()
- *   and clutter_actor_set_easing_duration().
+ *   of the children when allocating them
  */
 void
 clutter_table_layout_set_easing_duration (ClutterTableLayout *layout,
@@ -2555,9 +2557,7 @@ clutter_table_layout_set_easing_duration (ClutterTableLayout *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them. See clutter_actor_set_easing_mode()
- *   and clutter_actor_set_easing_duration().
+ * Deprecated: 1.12
  */
 guint
 clutter_table_layout_get_easing_duration (ClutterTableLayout *layout)
@@ -2578,7 +2578,7 @@ clutter_table_layout_get_easing_duration (ClutterTableLayout *layout)
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: No direct replacement is available
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 gint
 clutter_table_layout_get_row_count (ClutterTableLayout *layout)
@@ -2599,7 +2599,7 @@ clutter_table_layout_get_row_count (ClutterTableLayout *layout)
  *
  * Since: 1.4
  *
- * Deprecated: 1.18: No direct replacement is available
+ * Deprecated: 1.18: Use #ClutterGridLayout instead
  */
 gint
 clutter_table_layout_get_column_count (ClutterTableLayout *layout)
