@@ -31,6 +31,10 @@
 
 G_BEGIN_DECLS
 
+#if !defined(CLUTTER_ENABLE_COMPOSITOR_API) && !defined(CLUTTER_COMPILATION)
+#error "You need to define CLUTTER_ENABLE_COMPOSITOR_API before including clutter-evdev.h"
+#endif
+
 /**
  * ClutterOpenDeviceCallback:
  * @path: the device path
@@ -45,10 +49,13 @@ typedef int (*ClutterOpenDeviceCallback) (const char  *path,
 					  gpointer     user_data,
 					  GError     **error);
 
+CLUTTER_AVAILABLE_IN_1_16
 void  clutter_evdev_set_open_callback (ClutterOpenDeviceCallback callback,
 				       gpointer                  user_data);
 
+CLUTTER_AVAILABLE_IN_1_10
 void  clutter_evdev_release_devices (void);
+CLUTTER_AVAILABLE_IN_1_10
 void  clutter_evdev_reclaim_devices (void);
 
 /**
@@ -73,14 +80,25 @@ typedef void (*ClutterPointerConstrainCallback) (ClutterInputDevice *device,
 						 float              *y,
 						 gpointer            user_data);
 
+CLUTTER_AVAILABLE_IN_1_16
 void  clutter_evdev_set_pointer_constrain_callback (ClutterDeviceManager            *evdev,
 						    ClutterPointerConstrainCallback  callback,
 						    gpointer                         user_data,
 						    GDestroyNotify                   user_data_notify);
 
+CLUTTER_AVAILABLE_IN_1_16
 void               clutter_evdev_set_keyboard_map   (ClutterDeviceManager *evdev,
 						     struct xkb_keymap    *keymap);
 
+CLUTTER_AVAILABLE_IN_1_18
+struct xkb_keymap * clutter_evdev_get_keyboard_map (ClutterDeviceManager *evdev);
+
+CLUTTER_AVAILABLE_IN_1_18
+void clutter_evdev_set_keyboard_repeat (ClutterDeviceManager *evdev,
+                                        gboolean              repeat,
+                                        guint32               delay,
+                                        guint32               interval);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_EVDEV_H__ */
