@@ -774,6 +774,17 @@ clutter_backend_x11_create_stage (ClutterBackend  *backend,
   return stage;
 }
 
+static PangoDirection
+clutter_backend_x11_get_keymap_direction (ClutterBackend *backend)
+{
+  ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend);
+
+  if (G_UNLIKELY (backend_x11->keymap == NULL))
+    return PANGO_DIRECTION_NEUTRAL;
+
+  return _clutter_keymap_x11_get_direction (backend_x11->keymap);
+}
+
 static void
 clutter_backend_x11_class_init (ClutterBackendX11Class *klass)
 {
@@ -797,6 +808,8 @@ clutter_backend_x11_class_init (ClutterBackendX11Class *klass)
   backend_class->get_renderer = clutter_backend_x11_get_renderer;
   backend_class->get_display = clutter_backend_x11_get_display;
   backend_class->create_stage = clutter_backend_x11_create_stage;
+
+  backend_class->get_keymap_direction = clutter_backend_x11_get_keymap_direction;
 }
 
 static void
