@@ -46,10 +46,6 @@
 #include "clutter-private.h"
 #include "clutter-stage-private.h"
 
-#ifdef HAVE_XFIXES
-#include <X11/extensions/Xfixes.h>
-#endif
-
 #define STAGE_X11_IS_MAPPED(s)  ((((ClutterStageX11 *) (s))->wm_state & STAGE_X11_WITHDRAWN) == 0)
 
 static ClutterStageWindowIface *clutter_stage_window_parent_iface = NULL;
@@ -296,6 +292,14 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
                          height);
         }
     }
+  else
+    {
+      /* if the backing window hasn't been created yet, we just
+       * need to store the new window size
+       */
+      stage_x11->xwin_width = width;
+      stage_x11->xwin_height = height;
+    }
 }
 
 static inline void
@@ -366,22 +370,10 @@ set_cursor_visible (ClutterStageX11 *stage_x11)
 
   if (stage_x11->is_cursor_visible)
     {
-#if HAVE_XFIXES
-      if (stage_x11->cursor_hidden_xfixes)
-        {
-          XFixesShowCursor (backend_x11->xdpy, stage_x11->xwin);
-          stage_x11->cursor_hidden_xfixes = FALSE;
-        }
-#else
       XUndefineCursor (backend_x11->xdpy, stage_x11->xwin);
-#endif /* HAVE_XFIXES */
     }
   else
     {
-#if HAVE_XFIXES
-      XFixesHideCursor (backend_x11->xdpy, stage_x11->xwin);
-      stage_x11->cursor_hidden_xfixes = TRUE;
-#else
       XColor col;
       Pixmap pix;
       Cursor curs;
@@ -394,10 +386,23 @@ set_cursor_visible (ClutterStageX11 *stage_x11)
                                   1, 1);
       XFreePixmap (backend_x11->xdpy, pix);
       XDefineCursor (backend_x11->xdpy, stage_x11->xwin, curs);
-#endif /* HAVE_XFIXES */
     }
 }
 
+static void
+on_window_scaling_factor_notify (GObject         *settings,
+                                 GParamSpec      *pspec,
+                                 ClutterStageX11 *stage_x11)
+{
+  g_object_get (settings,
+                "window-scaling-factor", &stage_x11->scale_factor,
+                NULL);
+
+  clutter_stage_x11_resize (CLUTTER_STAGE_WINDOW (stage_x11),
+                            stage_x11->xwin_width,
+                            stage_x11->xwin_height);
+}
+
 static void
 clutter_stage_x11_unrealize (ClutterStageWindow *stage_window)
 {
@@ -839,10 +844,12 @@ clutter_stage_x11_set_scale_factor (ClutterStageWindow *stage_window,
 {
   ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
 
-  if (stage_x11->fixed_scale_factor)
+  if (stage_x11->scale_factor == factor)
     return;
 
   stage_x11->scale_factor = factor;
+
+  clutter_stage_x11_resize (stage_window, stage_x11->xwin_width, stage_x11->xwin_height);
 }
 
 static int
@@ -886,7 +893,7 @@ clutter_stage_x11_class_init (ClutterStageX11Class *klass)
 static void
 clutter_stage_x11_init (ClutterStageX11 *stage)
 {
-  const char *scale_str;
+  ClutterSettings *settings;
 
   stage->xwin = None;
   stage->xwin_width = 640;
@@ -897,24 +904,15 @@ clutter_stage_x11_init (ClutterStageX11 *stage)
   stage->is_foreign_xwin = FALSE;
   stage->fullscreening = FALSE;
   stage->is_cursor_visible = TRUE;
-  stage->cursor_hidden_xfixes = FALSE;
   stage->accept_focus = TRUE;
 
   stage->title = NULL;
 
-  scale_str = g_getenv ("CLUTTER_SCALE");
-  if (scale_str != NULL)
-    {
-      CLUTTER_NOTE (BACKEND, "Scale factor set using environment variable: %d ('%s')",
-                    atol (scale_str),
-                    scale_str);
-      stage->fixed_scale_factor = TRUE;
-      stage->scale_factor = atol (scale_str);
-      stage->xwin_width *= stage->scale_factor;
-      stage->xwin_height *= stage->scale_factor;
-    }
-  else
-    stage->scale_factor = 1;
+  settings = clutter_settings_get_default ();
+  g_signal_connect (settings, "notify::window-scaling-factor",
+                    G_CALLBACK (on_window_scaling_factor_notify),
+                    stage);
+  on_window_scaling_factor_notify (G_OBJECT (settings), NULL, stage);
 }
 
 static void
@@ -1194,26 +1192,6 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
         }
       break;
 
-    case EnterNotify:
-#if HAVE_XFIXES
-      if (!stage_x11->is_cursor_visible && !stage_x11->cursor_hidden_xfixes)
-        {
-          XFixesHideCursor (backend_x11->xdpy, stage_x11->xwin);
-          stage_x11->cursor_hidden_xfixes = TRUE;
-        }
-#endif
-      break;
-
-    case LeaveNotify:
-#if HAVE_XFIXES
-      if (stage_x11->cursor_hidden_xfixes)
-        {
-          XFixesShowCursor (backend_x11->xdpy, stage_x11->xwin);
-          stage_x11->cursor_hidden_xfixes = FALSE;
-        }
-#endif
-      break;
-
     case Expose:
       {
         XExposeEvent *expose = (XExposeEvent *) xevent;
